This page describes how search results are returned in the form of
"datasets". These are collections containing (i) the data table generated by the
search query, (ii) the data table in a CSV file format, and (iii) zipped light
curves for all objects corresponding to those matching the search query
conditions. These products are available for download from a permanent URL that
is associated with each search result. In addition, the data table on the
dataset page contains links to detailed per-object information (such as colors,
variability tags, and plots of phased light curves if period-finding was run).

[TOC]

## Dataset availability after queries

Since all queries in the LCC server framework run asynchronously and drop to a
background queue after 30 seconds of "active" time, a dataset may not be
considered "complete" until all light curves associated with it have been
collected into a ZIP file. Most queries finish within 30 seconds and when you
browse to the dataset page, the data table and other related information will be
immediately rendered. When a query, or the process of collecting the matching
object's light curve files into a ZIP file takes too long, the dataset page will
show up in an "in progress" state and will show a corresponding notification.

<figure class="figure">
  <img src="/server-static/lcc-server-dataset-in-progress.png"
       class="figure-img img-fluid"
       alt="An in-progress dataset ">
  <figcaption class="figure-caption text-center">
    The dataset page for an "in-progress" dataset
  </figcaption>
</figure>


## The dataset page header

The page will check if the dataset background process has completed every 15
seconds, so you can switch away to other tasks (and even run more queries in the
mean time). Once the search backend notifies the dataset's page of its task
completion, the dataset's status will change to "complete". The data table will
be populated with object rows given the columns requested from the database. If
there are more than 3,000 matches for a query, only the first 3,000 will be
rendered in the data table to keep the browser responsive. In this case, you can
download the full data table CSV and slice and dice it as needed
offline.

Queries that return more than 20,000 matches will not produce a light curve ZIP
file because it would take too long and take up too much space on the server. If
this happens, the data table CSV file will still be generated and will contain
links to each object's light curve file for individual download if needed, in
additional to the columns requested in the query. It's usually better to try to
refine your query in this case to get a smaller set of matching objects that
are more relevant, rather than trying to sift through a large number of them.

<figure class="figure">
  <img src="/server-static/lcc-server-dataset-query-info.png"
       class="figure-img img-fluid"
       alt="A complete dataset">
  <figcaption class="figure-caption text-center">
    The dataset page for a "complete" dataset
  </figcaption>
</figure>

The header at the top of the page includes information on the query producing
the dataset: the arguments parsed by the backend from the input parameters, the
number of objects in the dataset, and timing information. Clicking on the
collapsible headers in the page header will open the other sections; these
include the dataset products section and the data table column description
sections.

<div class="row align-items-end">
<div class="col-6">

<figure class="figure">
  <img src="/server-static/lcc-server-dataset-products.png"
       class="figure-img img-fluid"
       alt="Dataset product download links">
  <figcaption class="figure-caption text-center">
    Dataset product download links
  </figcaption>
</figure>

</div>

<div class="col-6">
<figure class="figure">
  <img src="/server-static/lcc-server-dataset-column-desc.png"
       class="figure-img img-fluid"
       alt="Data table column descriptions">
  <figcaption class="figure-caption text-center">
    Data table column descriptions
  </figcaption>
</figure>

</div>
</div>


## The dataset page data table

The data table contains all of the columns requested in the query. It will
expand horizontally to fit the column widths as required. The columns `db_oid`
(the object's database ID), `db_ra` (the object's database right ascension),
`db_decl` (the object's database declination), and `db_lcfname` (the object's
light curve file) are always returned with any query result, along with any
columns that had filters or sort conditions applied, and finally, any actual
columns requested in the query. Full-text search queries will return all columns
corresponding to full-text indexed fields in the database so one can quickly
find out what database column matched a full-text search query.

<figure class="figure">
  <img src="/server-static/lcc-server-dataset-complete.png"
       class="figure-img img-fluid"
       alt="Data table rows">
  <figcaption class="figure-caption text-center">
    Data table rows
  </figcaption>
</figure>


## Per-object information links

Each table row has a link to additional object information from the light curve
catalogs that LCC server has access to. Clicking on the link at the beginning of
each row will perform an object information look up for the object in that row,
and return it in the form of a pop-up window:

<figure class="figure">
  <img src="/server-static/lcc-server-object-info-basic.png"
       class="figure-img img-fluid"
       alt="Object information pop-up">
  <figcaption class="figure-caption text-center">
    Object information pop-up
  </figcaption>
</figure>

This pop-up window has two tabs. The first contains basic object information,
such as a DSS2 RED finder chart, a plot of the light curve, and magnitude and
color information. It also contains results of pre-computed cross-matches to
external catalogs such as GAIA and SIMBAD, as well as object IDs of any nearby
object's in the light curve that may blend the light from any prospective
variability. Finally, this tab contains comments on the object type based on its
colors and variability if they were present in the input data used by the LCC
server to generate its databases.

The second tab contains tiles of period-finding periodograms and phased light
curves for the highest three peaks in each periodogram. These can be useful for
a quick look at the object's variability before downloading its light curve for
additional processing offline.

<figure class="figure">
  <img src="/server-static/lcc-server-object-info-phasedlcs.png"
       class="figure-img img-fluid"
       alt="Object information pop-up phased LC tab">
  <figcaption class="figure-caption text-center">
    Object information pop-up phased LC tab
  </figcaption>
</figure>
